@@ -100,7 +100,7 @@ def parse_coverage_args(argv):
         "--compare-branch",
         metavar="BRANCH",
         type=str,
-        default="origin/master",
+        default="origin/main",
         help=COMPARE_BRANCH_HELP,
     )
 
